add

package
v0.0.0-...-d277e4d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package add provides the runner implementation for the `bujo add` command.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Add

type Add struct {
	Entry entry.Entry

	Bullet        glyph.Bullet
	Collection    string
	Message       string
	On            *time.Time
	Priority      bool
	Inspiration   bool
	Investigation bool

	Persistence store.Persistence
}

Add persists a new entry into the journal.

func (*Add) Do

func (n *Add) Do(ctx context.Context) error

Do creates the entry and prints the updated collection.

Jump to