strike

package
v0.0.0-...-d277e4d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package strike provides the runner logic for striking entries.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Strike

type Strike struct {
	ID          string
	Persistence store.Persistence
}

Strike marks an entry as struck out (irrelevant).

func (*Strike) Do

func (n *Strike) Do(ctx context.Context) error

Do executes the strike operation against the persistence layer.

Jump to