track

package
v0.0.0-...-d277e4d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Overview

Package track provides runners that summarize entry tracking data.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Track

type Track struct {
	Collection  string
	Persistence store.Persistence
}

Track records an occurrence entry for a collection.

func (*Track) Do

func (n *Track) Do(ctx context.Context) error

Do writes an occurrence entry and reprints the tracking summary.

Jump to